## 0.3.0

### Overview

Increase test coverage and update documentation.

### Features

- Added: PostgreSQL testing.
  - I added `env_sample` to connect to PostgreSQL instance.
- Added: Development and Usage sections in README.
- Changed: Up rev dependencies.
  - typing-extensions to 4.15.0.
  - psycopg to 3.2.10.
  - psycopg-binary to 3.2.10.
  - duckdb to 1.4.0.
